package com.wtkj.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.wtkj.entity.Contacts;
import com.wtkj.mapper.ContactsMapper;
import com.wtkj.service.IContactsService;
import lombok.AllArgsConstructor;
import org.springblade.core.mp.base.BaseServiceImpl;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.system.feign.ISysClient;
import org.springblade.system.vo.DeptVO;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @author Blizzard
 * @create at 2023-09-19 11:04
 * @describe
 */
@Service
@AllArgsConstructor
public class ContactsServiceImpl extends BaseServiceImpl<ContactsMapper, Contacts> implements IContactsService {

	private final ISysClient sysClient;

	@Override
	public IPage<Contacts> pageByTopDept(Long topDept, IPage<Contacts> page) {
		return page.setRecords(baseMapper.pageByTopDept(topDept, page));
	}

	@Override
	public IPage<DeptVO> deptPage(Long topDept, Query query) {
		IPage<DeptVO> page = new Page<>();
		List<Contacts> contacts = baseMapper.selectByTopDept(topDept);
		if (!CollectionUtils.isEmpty(contacts)) {
			Set<Long> collect = contacts.stream().map(Contacts::getRelatedTopDept).filter(Objects::nonNull).collect(Collectors.toSet());
			String ids = Func.join(collect);
			R<IPage<DeptVO>> rpc = sysClient.getDeptPage(ids, query);
			if (rpc.isSuccess()) {
				page = rpc.getData();
			}
		}
		return page;
	}
}
